@@ -257,7 +257,8 @@ class Collection(Resource):
         local_relationships = {
             self.table.lfkey_by_relationship_name[name]: value
             for name, value in env.relationships.items()
-            if name in self.table.lfkey_by_relationship_name
+            if name in self.table.lfkey_by_relationship_name and
+            value is not None
         }
         lfkeys = local_relationships.keys()
         lfkey_values = [id_.number for id_ in local_relationships.values()]
@@ -294,15 +295,16 @@ class Collection(Resource):
         local_relationships = {
             self.table.lfkey_by_relationship_name[name]: value
             for name, value in env.relationships.items()
-            if name in self.table.lfkey_by_relationship_name
+            if name in self.table.lfkey_by_relationship_name and
+            value is not None
         }
         lfkeys = local_relationships.keys()
         lfkey_values = [id_.number for id_ in local_relationships.values()]
         column_names = ', '.join(chain(env.attributes.keys(), lfkeys))
         length = len(env.attributes) + len(lfkeys)
-        column_values = ', '.join(
-            [f'${index}' for index in range(1, length + 1)])
-        if column_values:
+        if length > 0:
+            column_values = ', '.join(
+                [f'${index}' for index in range(1, length + 1)])
             stmt = (f'INSERT INTO data.{self.table.name} ({column_names}) '
                     f'VALUES ({column_values}) RETURNING id')
         else:
@@ -315,7 +317,7 @@ class Collection(Resource):
         try:
             async with env.lock:
                 async with env.connection.transaction():
-                    log.debug(f'{stmt}: {attribute_values}, ' f'{lfkey_values}')
+                    log.debug(f'{stmt}: {attribute_values}, {lfkey_values}')
                     env.id_number = await env.connection.fetchval(
                         stmt, *attribute_values, *lfkey_values)
                     env.event.set()
