@@ -136,7 +136,10 @@ class Object(Resource):
             if name in self.table.lfkey_by_relationship_name
         }
         lfkeys = local_relationships.keys()
-        lfkey_values = [id_.number for id_ in local_relationships.values()]
+        lfkey_values = [
+            getattr(id_, "number", None)
+            for id_ in local_relationships.values()
+        ]
         column_names = chain(env.attributes.keys(), lfkeys)
         column_values = ', '.join(
             f'{col} = ${index+2}' for index, col in enumerate(column_names))
@@ -146,8 +149,8 @@ class Object(Resource):
         try:
             async with env.lock:
                 async with env.connection.transaction():
-                    log.debug(f'{stmt}: {env.attributes.values()}, '
-                              f'{self.id.number}')
+                    log.debug(f'{stmt}: {env.obj.id.number}, '
+                              f'{env.attributes.values()}, {lfkey_values}')
                     result = await env.connection.execute(
                         stmt, env.obj.id.number, *env.attributes.values(),
                         *lfkey_values)
